@@ -5,16 +5,18 @@ Module of SqlContainer class.
 
 __author__ = 'https://github.com/akvilary'
 
-from typing import Optional, Self
+from typing import Optional, Self, Any
 
 import re
 
 from .sql_val import SqlVal
+from .utils.classes.filter_operator_manager import FilterOperatorManager
 from .utils.classes.string_convertible import StringConvertible
 from .utils.wrap_text import get_wrapped
+from .utils.indent_text import indent_lines
 
 
-class SqlContainer(StringConvertible):
+class SqlContainer(FilterOperatorManager, StringConvertible):
     """SqlContainer is invented to store prepared SQL text and is an end result of
     any SQL constracting manipulations (it is a product of SqlSection and SqlQuery instances).
 
@@ -45,9 +47,10 @@ class SqlContainer(StringConvertible):
         self.wrapper_text: Optional[str | StringConvertible] = None
         self.is_multiline_wrap_type: bool = True
 
+        self.rel_ind: int = 0  # relative indentation
+
         self.vars: dict = {}
-        if isinstance(text, SqlContainer):
-            self.vars.update(text.vars)
+        unite_container_vars(self, text)
 
     def __bool__(self):
         """True if self.text is True"""
@@ -60,7 +63,12 @@ class SqlContainer(StringConvertible):
 
     def __str__(self) -> str:
         """Convert SqlContainer instance to str"""
-        return get_string_representation(self.text, self.wrapper_text, self.is_multiline_wrap_type)
+        return get_string_representation(
+            self.text,
+            self.wrapper_text,
+            self.is_multiline_wrap_type,
+            self.rel_ind,
+        )
 
     def dumps(self) -> str:
         """Get SqlContainer as str and do replace placeholders by self.vars
@@ -77,7 +85,12 @@ class SqlContainer(StringConvertible):
                     str(SqlVal(value)),
                     text,
                 )
-        return get_string_representation(text, self.wrapper_text, self.is_multiline_wrap_type)
+        return get_string_representation(
+            text,
+            self.wrapper_text,
+            self.is_multiline_wrap_type,
+            self.rel_ind,
+        )
 
     def wrap(self, wrapper_text: str | StringConvertible = '', do_multiline: bool = None) -> Self:
         """
@@ -85,9 +98,9 @@ class SqlContainer(StringConvertible):
         Params:
             - wrapper_text: is text after wrapped parentheses.
             - do_multiline:
-                - if True then add parentheses in separate lines 
+                - if True then add parentheses in separate lines
                 and indent text body inside (but it do not split self.text in multi lines).
-                - if False then parentheses will be added without new lines and self.text will be 
+                - if False then parentheses will be added without new lines and self.text will be
                 not extra indented (but it do not convert self.text in one line).
 
         """
@@ -102,13 +115,30 @@ class SqlContainer(StringConvertible):
         self.is_multiline_wrap_type = True
         return self
 
+    def indent(self, num: int) -> Self:
+        """Add extra relative indentation for string representation"""
+        self.rel_ind = num
+        return self
+
 
 def get_string_representation(
     text: str,
     wrapper_text: Optional[str],
     is_wrap_multiline: bool = True,
+    rel_ind: int = 0,
 ) -> str:
     """Get text or wrap text by wrapper and return as string"""
     if wrapper_text is not None:
-        return get_wrapped(text, wrapper_text or '', is_wrap_multiline)
-    return str(text)
+        return get_wrapped(
+            text,
+            wrapper_text or '',
+            is_wrap_multiline,
+            rel_ind,
+        )
+    return indent_lines(str(text), rel_ind) if rel_ind else str(text)
+
+
+def unite_container_vars(container: SqlContainer, obj: Any):
+    """Unite container vars"""
+    if isinstance(obj, SqlContainer):
+        container.vars.update(obj.vars)
